@@ -2,7 +2,7 @@ package App::cpanlistchanges;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Algorithm::Diff;
 use CPAN::DistnameInfo;
@@ -58,7 +58,7 @@ sub show_changes {
         $to = undef if $to eq 'HEAD';
     }
 
-    my $dist = try { YAML::Load( $self->get("http://cpanmetadb.appspot.com/v1.0/package/$mod") ) };
+    my $dist = try { YAML::Load( $self->get("http://cpanmetadb.plackperl.org/v1.0/package/$mod") ) };
     unless ($dist->{distfile}) {
         warn "Couldn't find a module '$mod'. Skipping.\n";
         return;
